
import java.util.*;
import java.io.BufferedReader;
import java.io.InputStreamReader;
import java.io.IOException;

class expr_eval {

    public static void main(String[] args) {
        BufferedReader br = null;
        try {
	   br = new BufferedReader(new InputStreamReader(System.in));
        } catch (Exception e) {
           System.err.println("problem with BufferedReader");
           System.exit(1);
        }
	String theLine;
 	while(true) {
                try {
		            theLine = br.readLine();
                } catch (IOException ioe) {
                    break;
                }
		if (theLine == null) break;
		if (theLine.equals("quit")) break;
 		if (theLine.equals("")) continue;
		Tokenizer t = new Tokenizer(false, theLine);
		String token;
		token = t.token();
		if (token == null) break;
		Evaluator e = new Evaluator(token, t);
		//t.setDebug(true);
		long theResult = 0;
		try {
			theResult = e.exprEval();
			e.accept(null);
			System.out.println(theResult);
		} catch (SyntaxException se) {
			System.out.println("syntax error: " + se.getMessage());
		} catch (IllegalArgumentException iae) {
		     System.out.println("evaluation error: division by zero");
		} catch (ArithmeticException ae) {
			System.out.println("evaluation error: division by zero");
		}
	}
    }
}

class SyntaxException extends Exception  {
    public SyntaxException()  { super(); }
    public SyntaxException(String message)  {super(message); }
    public SyntaxException(String message, Exception inner) { super(message, inner); }

    // A constructor is needed for serialization when an 
    // exception propagates from a remoting server to the client.  
    //protected InvalidDepartmentException(System.Runtime.Serialization.SerializationInfo info,
    //   System.Runtime.Serialization.StreamingContext context) { }
}


class Evaluator {

    private Tokenizer t;
    private String theToken;
    
    public Evaluator(String token, Tokenizer Tok) {
	t = Tok;
	theToken = token;
    }

    /* Grammar:
	expr   ::= term { addop term }
	term   ::= factor { mulop factor }
	factor ::= number | '(' expr ')' 
    /* */

    public long exprEval() throws SyntaxException, ArithmeticException {
	long result = termEval();
	while (t.equals(theToken, "+") || t.equals(theToken, "-")) {
		String addop = theToken;
		theToken = t.token();
		long res2 = termEval();
		if (addop.equals("+")) result += res2;
		if (addop.equals("-")) result -= res2;
	}
	return result;
    }

    private long termEval()  throws SyntaxException, ArithmeticException {
	long result = factorEval();
	while (t.equals(theToken, "*") || t.equals(theToken, "/") || t.equals(theToken, "%")) {
		String mulop = theToken;
		theToken = t.token();
		long res2 = factorEval();
		if (mulop.equals("*")) result *= res2;
		if (mulop.equals("/")) {
 			//if (res2 == 0) throw new IllegalArgumentException("division by zero");
			result /= res2;
		}
		if (mulop.equals("%")) result %= res2;
	}
	return result;
    }

    private long factorEval() throws SyntaxException, ArithmeticException {
	if (t.isNumber(theToken)) {
		long result = new Long(theToken);
		theToken = t.token();
		return result;
	} else if (theToken.equals("(")) {
	    accept("(");
	    long result = exprEval();
	    accept(")");
	    return result;
	} else {
		throw new SyntaxException ("illegal factor token: \"" + theToken + "\"");
	}
    }

    // must be in this class, *not* Tokenizer
    public void accept(String expected) throws SyntaxException {
        if (theToken == null && expected == null 
            || theToken !=null && theToken.equals(expected)) {
                theToken = t.token();
        } else {
	    if (theToken == null) theToken = "<EOL>";
	    throw new SyntaxException ("expected \""+expected+"\"; got \""+ theToken+ "\"");
            //t.error("expected \""+expected+"\"; got \""+ theToken+ "\"");
        }
    }
}
